@@ -8,7 +8,7 @@ use WWW::Crawler::Mojo::UserAgent;
 use WWW::Crawler::Mojo::ScraperUtil qw{
   collect_urls_css html_handler_presets reduce_html_handlers resolve_href decoded_body};
 use Mojo::Message::Request;
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 has clock_speed       => 0.25;
 has html_handlers     => sub { html_handler_presets() };
@@ -174,7 +174,7 @@ sub _make_child {
 
   my $resolved = resolve_href($base, $url);
 
-  return unless ($resolved->scheme =~ qr{http|https|ftp|ws|wss});
+  return unless ($resolved->scheme =~ qr{^(http|https|ftp|ws|wss)$});
 
   my $child
     = $job->child(url => $resolved, literal_uri => $url, context => $context);
